<?php
/**
 * Yii mailchimp form
 *
 * @author Marc Oliveras Galvez <oligalma@gmail.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */

namespace app\extensions\mailchimpform;

use Yii;
use yii\web\View;
use yii\base\Widget;
use yii\helpers\Html;

class MailchimpForm extends Widget
{
    public $apiKey;
    public $listId;
    public $showName;
    
	public function run()
	{
	$assetsPath = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'assets';
	$assetsUrl = Yii::$app->getAssetManager()->publish($assetsPath);
	$this->getView()->registerCssFile($assetsUrl[1] . '/style.css', [], 'mailchimpform');
		
        if(isset($_POST['subscribe-submit']))
        {
            if(!empty($_POST['subscribe-email']) && (!$this->showName || (!empty($_POST['subscribe-first-name']) && !empty($_POST['subscribe-last-name']))))
            {                
                require __DIR__ . '/lib/Mailchimp.php';
                
                $api_key = $this->apiKey;
                $list_id = $this->listId;
                $email = array('email' => $_POST['subscribe-email']);

                if($this->showName)
                    $merge_vars = array('FNAME' => $_POST['subscribe-first-name'],'LNAME' => $_POST['subscribe-last-name']);
                else
                    $merge_vars = array();
                
                $email_type = 'html';
                $double_optin = true;
                
                $Mailchimp = new \Mailchimp($api_key);
                $Mailchimp_Lists = new \Mailchimp_Lists($Mailchimp);
                
                try
                {
                    $subscriber = $Mailchimp_Lists->subscribe($list_id, $email, $merge_vars, $email_type, $double_optin);
                }
                catch(\Exception $e)
                {
                    $message = Html::tag('span', $e->getMessage(), array('class' => 'subscribe-red'));   
                }
                
                if (!empty($subscriber['leid'])) {
                   $message = Html::tag('span', 'You have been subscribed successfully.', array('class' => 'subscribe-green'));
                }
            }
            else
            {
                $message = Html::tag('span', 'You need to fill all fields.', array('class' => 'subscribe-red'));   
            }
        }
        
        echo Html::beginTag('div', array('id' => 'subscribe-div'));

        if(isset($message))
            echo Html::tag('div', $message, array('id' => 'subscribe-message'));
        
	echo Html::beginForm();
        echo Html::tag('span', 'Email', array('class' => 'subscribe-label'));
        echo Html::textInput('subscribe-email', (empty($_POST['subscribe-email']) ? '' : $_POST['subscribe-email']), array('id' => 'subscribe-email', 'type' => 'email', 'required' => 'required'));
            
        if($this->showName)
        {
            echo Html::tag('span', 'First name', array('class' => 'subscribe-label'));
            echo Html::textInput('subscribe-first-name',(empty($_POST['subscribe-first-name']) ? '' : $_POST['subscribe-first-name']), array('id' => 'subscribe-first-name', 'required' => 'required'));
            echo Html::tag('span', 'Last name', array('class' => 'subscribe-label'));
            echo Html::textInput('subscribe-last-name',(empty($_POST['subscribe-last-name']) ? '' : $_POST['subscribe-last-name']), array('id' => 'subscribe-last-name', 'required' => 'required'));
        }
            
        echo Html::submitButton('SUBSCRIBE', array('id' => 'subscribe-submit', 'name' => 'subscribe-submit'));
        echo Html::endForm();
        echo Html::endTag('div');
	}
}